@@ -474,10 +474,11 @@ private:
 	bool create(const char *id, keynode *node);
 	keynode *find(const char *id);
 
-	void confirm(const char *user);
+	void confirm(void);
 	void dump(FILE *fp);
 
 public:
+	static shell::logmode_t logmode;
 	static unsigned uid;
 	static const char *sipusers;
 	static const char *sipadmin;
@@ -496,12 +497,10 @@ public:
 	static void release(stack::subnet *access);
 	static void release(keynode *node);
 	static void release(usernode& user);
-	static void reload(const char *uid);
+	static void reload(void);
 	static Socket::address *getContact(const char *id);
 	static void plugins(const char *argv0, const char *names);
-	static void usage(void);
-	static void version(void);
-	static void run(const char *user);
+	static void run(void);
 	static void stop(void);
 	static caddr_t allocate(size_t size, LinkedObject **list, volatile unsigned *count = NULL);
 	static unsigned allocate(void);
@@ -729,5 +728,54 @@ private:
 	static bool isProxied(const char *source, const char *target, struct sockaddr_storage *peering);
 };
 
+class __LOCAL history : public OrderedObject, public process
+{
+public:
+    char text[128];
+
+    history(shell::loglevel_t lid, const char *msg);
+
+    void set(shell::loglevel_t lid, const char *msg);
+
+    static void add(shell::loglevel_t lid, const char *msg);
+	static void set(unsigned size);
+	static void out(void);
+};
+
+#ifdef HAVE_SIGWAIT
+#include <signal.h>
+
+class __LOCAL signals : private JoinableThread
+{
+private:
+    bool shutdown;
+    bool started;
+
+    sigset_t sigs;
+
+    void run(void);
+    void cancel(void);
+
+    signals();
+    ~signals();
+
+    static signals thread;
+
+public:
+    static void setup(void);
+    static void start(void);
+    static void stop(void);
+};
+
+#else
+class __LOCAL signals
+{
+public:
+    static void setup(void);
+    static void start(void);
+    static void stop(void);
+};
+#endif
+
 END_NAMESPACE
 
